@@ -337,7 +337,9 @@ void AgentTimer::response(AbstractProcessLoop& events_loop)
 {
     Application* app = static_cast<Application*>(events_loop.get_owner());
     app->deactivate_interval_timer(this);
-    THROW_ERR(SPICEC_ERROR_CODE_AGENT_TIMEOUT, "vdagent timeout");
+
+    LOG_WARN("timeout while waiting for agent response");
+    _client->send_main_attach_channels();
 }
 
 class MainChannelLoop: public MessageHandlerImp<RedClient, SPICE_CHANNEL_MAIN> {
@@ -357,6 +359,7 @@ RedClient::RedClient(Application& application)
     , _auto_display_res (false)
     , _agent_reply_wait_type (-1)
     , _aborting (false)
+    , _msg_attach_channels_sent(false)
     , _agent_connected (false)
     , _agent_mon_config_sent (false)
     , _agent_disp_config_sent (false)
@@ -367,7 +370,7 @@ RedClient::RedClient(Application& application)
     , _agent_out_msg_size (0)
     , _agent_out_msg_pos (0)
     , _agent_tokens (0)
-    , _agent_timer (new AgentTimer())
+    , _agent_timer (new AgentTimer(this))
     , _agent_caps_size(0)
     , _agent_caps(NULL)
     , _migrate (*this)
@@ -641,7 +644,7 @@ void RedClient::send_agent_monitors_config()
         THROW(" monitors query failed");
     }
 
-    double min_distance = HUGE;
+    double min_distance = INFINITY;
     int dx = 0;
     int dy = 0;
     int i;
@@ -963,19 +966,16 @@ void RedClient::handle_init(RedPeer::InMessage* message)
         agent_start.num_tokens = ~0;
         _marshallers->msgc_main_agent_start(msg->marshaller(), &agent_start);
         post_message(msg);
-    }
-
-    if (_agent_connected) {
         send_agent_announce_capabilities(true);
         if (_auto_display_res) {
            send_agent_monitors_config();
         }
-    }
-
-    if (!_auto_display_res && _display_setting.is_empty()) {
-        post_message(new Message(SPICE_MSGC_MAIN_ATTACH_CHANNELS));
-    } else {
         _application.activate_interval_timer(*_agent_timer, AGENT_TIMEOUT);
+    } else {
+        if (_auto_display_res || !_display_setting.is_empty()) {
+            LOG_WARN("no agent running, display options have been ignored");
+        }
+        send_main_attach_channels();
     }
 }
 
@@ -1022,6 +1022,15 @@ void RedClient::handle_agent_disconnected(RedPeer::InMessage* message)
     _agent_connected = false;
 }
 
+void RedClient::send_main_attach_channels(void)
+{
+    if (_msg_attach_channels_sent)
+        return;
+
+    post_message(new Message(SPICE_MSGC_MAIN_ATTACH_CHANNELS));
+    _msg_attach_channels_sent = true;
+}
+
 void RedClient::on_agent_announce_capabilities(
     VDAgentAnnounceCapabilities* caps, uint32_t msg_size)
 {
@@ -1043,6 +1052,17 @@ void RedClient::on_agent_announce_capabilities(
         // not sending the color depth through send_agent_monitors_config, since
         // it applies only for attached screens.
         send_agent_display_config();
+    } else if (!_auto_display_res) {
+        /* some agents don't support monitors/displays agent messages, so
+         * we'll never reach on_agent_reply which sends this
+         * ATTACH_CHANNELS message which is needed for client startup to go
+         * on.
+         */
+        if (!_display_setting.is_empty()) {
+            LOG_WARN("display options have been requested, but the agent doesn't support these options");
+        }
+        send_main_attach_channels();
+        _application.deactivate_interval_timer(*_agent_timer);
     }
 }
 
@@ -1061,7 +1081,7 @@ void RedClient::on_agent_reply(VDAgentReply* reply)
     case VD_AGENT_MONITORS_CONFIG:
     case VD_AGENT_DISPLAY_CONFIG:
         if (_agent_reply_wait_type == reply->type) {
-            post_message(new Message(SPICE_MSGC_MAIN_ATTACH_CHANNELS));
+            send_main_attach_channels();
             _application.deactivate_interval_timer(*_agent_timer);
             _agent_reply_wait_type = -1;
         }
