@@ -70,7 +70,7 @@ void RedPeer::cleanup()
     }
 }
 
-void RedPeer::connect_unsecure(const char* host, int portnr)
+void RedPeer::connect_to_peer(const char* host, int portnr)
 {
     struct addrinfo ai, *result = NULL, *e;
     char uaddr[INET6_ADDRSTRLEN+1];
@@ -106,7 +106,7 @@ void RedPeer::connect_unsecure(const char* host, int portnr)
             getnameinfo((struct sockaddr*)e->ai_addr, e->ai_addrlen,
                         uaddr,INET6_ADDRSTRLEN, uport,32,
                         NI_NUMERICHOST | NI_NUMERICSERV);
-            LOG_INFO("Trying %s %s", uaddr, uport);
+            DBG(0, "Trying %s %s", uaddr, uport);
             if (::connect(_peer, e->ai_addr, e->ai_addrlen) == SOCKET_ERROR) {
                 err = sock_error();
                 LOG_INFO("Connect failed: %s (%d)",
@@ -115,7 +115,7 @@ void RedPeer::connect_unsecure(const char* host, int portnr)
                 _peer = -1;
                 continue;
             }
-            LOG_INFO("Connected to %s %s", uaddr, uport);
+            DBG(0, "Connected to %s %s", uaddr, uport);
             break;
         }
         lock.unlock();
@@ -132,6 +132,13 @@ void RedPeer::connect_unsecure(const char* host, int portnr)
     }
 }
 
+void RedPeer::connect_unsecure(const char* host, int portnr)
+{
+    connect_to_peer(host, portnr);
+    ASSERT(_ctx == NULL && _ssl == NULL && _peer != INVALID_SOCKET);
+    LOG_INFO("Connected to %s %d", host, portnr);
+}
+
 bool RedPeer::verify_pubkey(X509* cert, const HostAuthOptions::PublicKey& key)
 {
     EVP_PKEY* cert_pubkey = NULL;
@@ -472,9 +479,11 @@ void RedPeer::connect_secure(const ConnectionOptions& options, const char* host)
     int return_code;
     int auth_flags;
     SslVerifyCbData auth_data;
+    int portnr = options.secure_port;
 
-    connect_unsecure(host, options.secure_port);
+    connect_to_peer(host, portnr);
     ASSERT(_ctx == NULL && _ssl == NULL && _peer != INVALID_SOCKET);
+    LOG_INFO("Connected to %s %d", host, portnr);
 
     try {
 #if OPENSSL_VERSION_NUMBER >= 0x10000000L
